docx\_parser\_converter.docx\_to\_txt.converters.paragraph\_converter module
============================================================================

.. automodule:: docx_parser_converter.docx_to_txt.converters.paragraph_converter
   :members:
   :undoc-members:
   :show-inheritance:
